@@ -2,7 +2,7 @@
 from stonecharioteer.logger import logger, configure_logger
 
 
-def config(cfg: dict):
+def config(cfg):
     """This function modifies the global variables, injecting
     parameters required to customize qtile."""
     configure_logger()
