@@ -7,7 +7,7 @@ from stonecharioteer.qtile.inputs import Keyboard, MOD
 from stonecharioteer.utils.displays import get_display_info
 
 
-def configure_keymaps(groups, cfg: dict):
+def configure_keymaps(groups, cfg):
     """Configures keymaps"""
     terminal = os.environ.get("QTILE_TERMINAL", guess_terminal())
     Super = [MOD.value]
@@ -22,9 +22,9 @@ def configure_keymaps(groups, cfg: dict):
         Key(Super, "k", lazy.layout.up(), desc="Move focus up"),
         Key(
             Super,
-            "space",
-            lazy.layout.next(),
-            desc="Move window focus to other window",
+            "m",
+            lazy.window.toggle_maximize(),
+            desc="Toggle Maximize Window",
         ),
         # Move windows between left/right columns or move up/down in current stack.
         # Moving out of range in Columns layout will create new column.
@@ -65,6 +65,7 @@ def configure_keymaps(groups, cfg: dict):
             desc="Toggle between split and unsplit sides of stack",
         ),
         Key(Super, "Return", lazy.spawn(terminal), desc="Launch terminal"),
+        Key(SuperControl, "s", lazy.spawn("xsecurelock"), desc="Lock screen with xsecurelock"),
         # Toggle between different layouts as defined below
         Key(Super, "Tab", lazy.next_layout(), desc="Toggle between layouts"),
         Key(Super, "w", lazy.window.kill(), desc="Kill focused window"),
@@ -120,7 +121,7 @@ def configure_keymaps(groups, cfg: dict):
         )
 
     monitors = cfg.get("monitors", [])
-    for monitor in monitors.keys():
+    for monitor in monitors:
        connector = monitor["connector"]
        keymap = monitor["keymap"]
        jerry_command = f"jerry -m {connector}" 
